結果
| 問題 | No.227 簡単ポーカー |
| コンテスト | |
| ユーザー |
zombietan
|
| 提出日時 | 2016-05-04 12:14:24 |
| 言語 | Python3 (3.15.0 + numpy 2.5.4 + scipy 1.18.1 + ACL) |
| 結果 |
AC
不安定
|
| 実行時間 | 21 ms / 5,000 ms |
| + 755µs | |
| コード長 | 395 bytes |
| 記録 | |
| コンパイル時間 | 116 ms |
| コンパイル使用メモリ | 15,104 KB |
| 実行使用メモリ | 11,008 KB |
| 最終ジャッジ日時 | 2026-10-11 03:05:00 |
| 合計ジャッジ時間 | 1,519 ms |
|
ジャッジサーバーID (参考情報) |
judge1_0 / judge3_0 |
(要ログイン)
| ファイルパターン | 結果 |
|---|---|
| other | AC * 15 |
ソースコード
from itertools import groupby
card = sorted([int(x) for x in input().split()])
pats = {
(2, 3): "FULL HOUSE",
(1, 1, 3): "THREE CARD",
(1, 2, 2): "TWO PAIR",
(1, 1, 1, 2): "ONE PAIR",
(1, 1, 1, 1, 1): "NO HAND",
(1, 4): "NO HAND",
(5,): "NO HAND"
}
hand = tuple(sorted([len(list(g)) for k, g in groupby(card)]))
print(pats[hand])
zombietan